These files contains a subset of the data used in Githumbi et al. (submitted) *Understanding Eastern African Montane Forest Evolution since the end of the Last Glacial Maxima.*

`mapping.xlsx` defined PFTs, and the mappings from PFTs to biomes and taxas to PFTs.

`sites.xlsx` contains pollen samples for the sites that are already available in Neotoma or have been submitted to the database.  All samples are pollen counts.
